@@ -1,7 +1,7 @@
 ###
 # Copyright (c) 2002-2005, Jeremiah Fincher
 # Copyright (c) 2009, James McCoy
-# Copyright (c) 2010-2021, The Limnoria Contributors
+# Copyright (c) 2010-2021, Valentin Lorentz
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -118,7 +118,7 @@ def strError(e):
 
 # Used to build defaultHeaders
 baseDefaultHeaders = {
-    'User-agent': 'Mozilla/5.0 (compatible; utils.web python module)'
+    'User-agent': 'Mozilla/5.0 (compatible; utils.web Limnoria module)'
     }
 
 # overridable by other modules/plugins.
